@@ -63,7 +63,8 @@ trans_code_to_country (gchar *code)
 		{"gr","Ελλάδα"},
 		{"il","ישראל"},
 		{"hu","Magyarország"},
-		{"it","Italia"}, /* 20 */
+		{"in","India"}, /* 20 */
+		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
 		{"kk","Қазақстан"},
 		{"no","Norge"},
@@ -71,9 +72,10 @@ trans_code_to_country (gchar *code)
 		{"pk","پاکستان"},
 		{"pt","Portugal"},
 		{"ru","Россия"},
-		{"se","Sverige"},
+		{"sl","Slovenija"},
+		{"se","Sverige"}, /* 30 */
 		{"tr","Türkiye"},
-		{"ua","Україна"}, /* 30 */
+		{"ua","Україна"},
 		{"uk","United Kingdom"},
 		{"us","USA"},
 		{"",""},
@@ -81,8 +83,6 @@ trans_code_to_country (gchar *code)
 		{"",""},
 		{"",""},
 		{"",""},
-		{"",""},
-		{"",""},
 		{"",""}
 	};
 
@@ -224,7 +224,9 @@ trans_lang_has_stopmark ()
 
 	hlp = main_preferences_get_string ("interface", "language");
 	stopmark = g_str_has_prefix (hlp, "ur") ||
-		   g_str_has_prefix (hlp, "bn");
+		   g_str_has_prefix (hlp, "ar") ||
+		   g_str_has_prefix (hlp, "bn") ||
+		   g_str_has_prefix (hlp, "pa");
 	g_free (hlp);
 
 	return (!stopmark);
@@ -401,11 +403,17 @@ trans_set_combo_language ()
 		g_free (langcode);
 	}
 	if (i_env == -1)
-		g_error ("set_combo_language() ==> the locale \"%s\" is not available!", tmp_code);
+	{
+		g_warning ("set_combo_language() ==> the locale \"%s\" is not available!", tmp_code);
+		g_message ("Using \"C\" as language code.");
+		g_free (tmp_code);
+		tmp_code = g_strdup ("C");
+		main_preferences_set_string ("interface", "language", "C");
+		gtk_combo_box_set_active (cmb, 8);
+	}
 	else
 		gtk_combo_box_set_active (cmb, i_env);
 
-
 	callbacks_shield_set (FALSE);
 
 	if (! recur)
