@@ -43,10 +43,12 @@
 "Қазақ (kk) [jtsuken_kk]\n" \
 "Кыргызча (ky) [jtsuken_ru]\n" \
 "Nederlands (nl) [qwerty_us]\n" \
+"Punjabi (pa) [gumurkhi_in_jehlum]\n" \
 "Polski (pl) [qwerty_pl_us]\n" \
 "Português (pt_BR) [qwerty_br_abnt2]\n" \
 "Русский (ru) [jtsuken_ru]\n" \
 "Suomen kieli (fi) [querty_se]\n"\
+"Slovenščina (sl) [qwertz_sl]\n" \
 "Svenska (sv) [qwerty_se]\n" \
 "తెలుగు (te) [qwerty_us]\n" \
 "Українська (uk) [jtsuken_ua]\n" \
